@@ -1,24 +1,23 @@
+#
+# This file is part of Config-Model-OpenSsh
+#
+# This software is Copyright (c) 2011 by Dominique Dumont.
+#
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+#
 [
           {
             'class_description' => 'Model of /etc/ssh/ssh_config or ~/.ssh/config',
             'include_after' => 'Host',
             'read_config' => [
                                {
-                                 'function' => 'ssh_read',
-                                 'backend' => 'custom',
-                                 'class' => 'Config::Model::OpenSsh',
+                                 'backend' => 'OpenSsh::Ssh',
                                  'config_dir' => '/etc/ssh'
                                }
                              ],
             'name' => 'Ssh',
-            'write_config' => [
-                                {
-                                  'function' => 'ssh_write',
-                                  'backend' => 'custom',
-                                  'class' => 'Config::Model::OpenSsh',
-                                  'config_dir' => '/etc/ssh'
-                                }
-                              ],
             'include' => [
                            'Ssh::HostElement'
                          ],
@@ -36,10 +35,12 @@
                              'level' => 'important',
                              'cargo' => {
                                           'type' => 'node',
-                                          'config_class_name' => 'Ssh::HostBlock'
+                                          'config_class_name' => 'Ssh::HostElement'
                                         },
-                             'type' => 'list',
-                             'description' => "The declarations make in 'parameters' are applied only to the hosts that match one of the patterns given in pattern elements. A single \x{2018}*\x{2019} as a pattern can be used to provide global defaults for all hosts. The host is the hostname argument given on the command line (i.e. the name is not converted to a canonicalized host name before matching)."
+                             'ordered' => '1',
+                             'type' => 'hash',
+                             'description' => "The declarations make in 'parameters' are applied only to the hosts that match one of the patterns given in pattern elements. A single \x{2018}*\x{2019} as a pattern can be used to provide global defaults for all hosts. The host is the hostname argument given on the command line (i.e. the name is not converted to a canonicalized host name before matching). Since the first obtained value for each parameter is used, more host-specific declarations should be given near the beginning of the hash (which takes order into account), and general defaults at the end.",
+                             'index_type' => 'string'
                            }
                          ]
           }
